@@ -2,8 +2,9 @@
 
 from __future__ import absolute_import, unicode_literals
 import json
-from growingio_tracker.data_parser import JsonParser
 import snappy
+import six
+from growingio_tracker.data_parser import JsonParser
 
 
 class SnappyParser(JsonParser):
@@ -24,11 +25,18 @@ class SnappyParser(JsonParser):
         return compress_data
 
     def _xor_crypt(self, raw_data, password):
-        xor = bytearray()
-        for nowByte in raw_data:
-            newByte = nowByte ^ int(password & 0xff)
-            xor.extend(bytes([newByte]))
-        return xor
+        if six.PY3:
+            xor = bytearray()
+            for nowByte in bytearray(raw_data):
+                newByte = nowByte ^ int(password & 0xff)
+                xor.extend(bytes([newByte]))
+            return xor
+        elif six.PY2:
+            xor = ''.join(chr(ord(x) ^ (password & 0xff)) for (x) in raw_data)
+            return xor
+        else:
+            self._crypt_data = False
+            return raw_data
 
     def get_headers(self):
         if self._crypt_data:
